summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorJoerg Roedel <jroedel@suse.de>2024-04-26 13:54:13 +0300
committerJoerg Roedel <jroedel@suse.de>2024-04-26 13:54:13 +0300
commit5dc72c8a146ddcfc568265c8088e90d8e996d340 (patch)
tree0ec46a798323b9c64f896f71493b7d801b92e458 /include
parenta4eecd720546527d9c3091231b531e8ca18ba718 (diff)
parent212c5c078d83d780cf2873ca931df135771e8bb7 (diff)
downloadlinux-5dc72c8a146ddcfc568265c8088e90d8e996d340.tar.xz
Merge branch 'memory-observability' into x86/amd
Diffstat (limited to 'include')
-rw-r--r--include/linux/mmzone.h5
1 files changed, 4 insertions, 1 deletions
diff --git a/include/linux/mmzone.h b/include/linux/mmzone.h
index c11b7cde81ef..8f9c9590a42c 100644
--- a/include/linux/mmzone.h
+++ b/include/linux/mmzone.h
@@ -205,7 +205,10 @@ enum node_stat_item {
NR_KERNEL_SCS_KB, /* measured in KiB */
#endif
NR_PAGETABLE, /* used for pagetables */
- NR_SECONDARY_PAGETABLE, /* secondary pagetables, e.g. KVM pagetables */
+ NR_SECONDARY_PAGETABLE, /* secondary pagetables, KVM & IOMMU */
+#ifdef CONFIG_IOMMU_SUPPORT
+ NR_IOMMU_PAGES, /* # of pages allocated by IOMMU */
+#endif
#ifdef CONFIG_SWAP
NR_SWAPCACHE,
#endif